Summary: An MRTG package that integrates the SNMP features of Squid.
Name: anemone
Version: 1.1
Release: 1
Copyright: GPL
Group: Networking
Vendor: The Electric Connection (http://www.electricc.com)
Packager: Erik Lotspeich <erik@electricc.com>
URL: http://anemone.elctech.com/
Requires: tomahawk
Conflicts: gd,gd-devel,mrtg
Source: mrtg.tar.gz
Source1: gd-1.8.3.tar.gz
Source2: additions.tar.gz

%description
Anemone integrates the flexible real-time status graphic capabilities
of MRTG with the powerful SNMP data-reporting facilities of the Squid
accelerator cache.  This combination provides real-time graphing of
web-server usage as well as other useful real-time information.

%prep
# Make sure that the packages are not installed before the cleanup
# and build takes place.
#
if /bin/rpm -q anemone ; then
rpm -e anemone
fi
#
# Clean up the host system before any build attempt takes place.
# This assures that the build will be a clean one.
#
rm -f /usr/bin/bdftogd
rm -f /usr/bin/gd2copypal
rm -f /usr/bin/gd2topng
rm -f /usr/bin/gdparttopng
rm -f /usr/bin/gdtopng
rm -f /usr/bin/pngtogd
rm -f /usr/bin/pngtogd2
rm -f /usr/bin/webpng
rm -f /usr/include/gd.h
rm -f /usr/include/gd_io.h
rm -f /usr/include/gdcache.h
rm -f /usr/include/gdfontg.h
rm -f /usr/include/gdfontl.h
rm -f /usr/include/gdfontmb.h
rm -f /usr/include/gdfonts.h
rm -f /usr/include/gdfontt.h
rm -f /usr/lib/libgd.a
rm -rf /etc/httpd/mrtg
rm -rf /home/httpd/html/mrtg

# If the directories exist, retar the archive so that the package
# maintains the newest version.
if [ -d $RPM_SOURCE_DIR/additions ]; then
cd $RPM_SOURCE_DIR
rm -f additions.tar.gz
tar czvf additions.tar.gz additions
fi

%setup -n mrtg-2.8.12 -b 0
%setup -n gd-1.8.3 -b 1
%setup -n additions -b 2

%build
cd $RPM_BUILD_DIR/gd-1.8.3
mv Makefile Makefile-

# Create a temporary file for sed to use to process the httpd.conf file.
cat > makefile.sed <<EOM
s/^INSTALL_LIB.*/INSTALL_LIB=\/usr\/lib/
s/^INSTALL_INCLUDE.*/INSTALL_INCLUDE=\/usr\/include/
s/^INSTALL_BIN.*/INSTALL_BIN=\/usr\/bin/
EOM

# Process the just-created file with sed, update the httpd.conf
# file, and delete the temporary file.
sed -f makefile.sed Makefile- > Makefile
rm -f makefile.sed

make
make install

cd $RPM_BUILD_DIR/mrtg-2.8.12
./configure
make

%install
# Create the mrtg directory in the Apache directory structure.
mkdir -p /etc/httpd/mrtg
mkdir -p /etc/httpd/admin
# Copy in the necessary files so that mrtg will run.
cd $RPM_BUILD_DIR/mrtg-2.8.12
cp -a doc images run /etc/httpd/mrtg
cp $RPM_BUILD_DIR/additions/mrtg.conf /etc/httpd/mrtg/run
mkdir -p /home/httpd/html/mrtg
cp -a $RPM_BUILD_DIR/mrtg-2.8.12/images/*png /home/httpd/html/mrtg
# Copy in file for MRTG graph viewer interface
cp -a $RPM_BUILD_DIR/additions/viewgraph.pl /etc/httpd/admin
# Copy in files for MRTG administration interface
cp -a $RPM_BUILD_DIR/additions/mrtg-admin.pl /etc/httpd/admin
cp -a $RPM_BUILD_DIR/additions/Mrtg.pm /etc/httpd/admin

%pre

%post
# Set up some default variables
APACHE_CONF_DIR=/etc/httpd/conf
SQUID_CONF_DIR=/etc/squid

# Add necessary lines to squid.conf to enable SNMP if they
# are not present already.
grep -e "^acl  *snmppublic  *snmp_community  *public" $SQUID_CONF_DIR/squid.conf > /dev/null
if [ $? -ne 0 ]; then
echo "acl snmppublic snmp_community public" >> $SQUID_CONF_DIR/squid.conf
fi

grep -e "^snmp_access  *allow  *snmppublic  *localhost" $SQUID_CONF_DIR/squid.conf > /dev/null
if [ $? -ne 0 ]; then
echo "snmp_access allow snmppublic localhost" >> $SQUID_CONF_DIR/squid.conf
fi

grep -e "^snmp_access  *deny  *all" $SQUID_CONF_DIR/squid.conf > /dev/null
if [ $? -ne 0 ]; then
echo "snmp_access deny all" >> $SQUID_CONF_DIR/squid.conf
fi

# Restart squid after the change has completed

/usr/bin/squid -k reconfigure

# Add an entry to /etc/crontab so that
# MRTG will generate new graphs every five minutes.
grep -e "^.*root  *\/etc\/httpd\/mrtg\/run\/mrtg  *\/etc\/httpd\/mrtg\/run\/mrtg.conf" /etc/crontab > /dev/null
if [ $? -ne 0 ]; then
echo "Adding entry to /etc/crontab to run mrtg every five minutes..."
echo "*/5 * * * * root /etc/httpd/mrtg/run/mrtg /etc/httpd/mrtg/run/mrtg.conf" >> /etc/crontab
fi

# Run MRTG upon install
echo "Running MRTG for the first time..."
/etc/httpd/mrtg/run/mrtg /etc/httpd/mrtg/run/mrtg.conf > /dev/null 2>&1

%preun
# Set up some default variables
APACHE_CONF_DIR=/etc/httpd/conf
SQUID_CONF_DIR=/etc/squid

# Remove entry from /etc/crontab that
# causes MRTG to run.
mv /etc/crontab /etc/crontab-
sed -e "/root  *\/etc\/httpd\/mrtg\/run\/mrtg/d" /etc/crontab- > /etc/crontab

# Remove SNMP configuration in squid.conf
cd $SQUID_CONF_DIR
mv squid.conf squid.conf-

# Create a temporary file for sed to use to process the httpd.conf file.
cat > squidconfig.sed <<EOF
/acl  *snmppublic  *snmp_community  *public/d
/snmp_access  *allow  *snmppublic  *localhost/d
/snmp_access  *deny  *all/d
EOF

# Process the just-created file with sed, update the squid.conf
# file, and delete the temporary file.
sed -f squidconfig.sed squid.conf- > squid.conf
rm -f squidconfig.sed

%postun

%files
# GD files
/usr/bin/bdftogd
/usr/bin/gd2copypal
/usr/bin/gd2topng
/usr/bin/gdparttopng
/usr/bin/gdtopng
/usr/bin/pngtogd
/usr/bin/pngtogd2
/usr/bin/webpng
/usr/include/gd.h
/usr/include/gd_io.h
/usr/include/gdcache.h
/usr/include/gdfontg.h
/usr/include/gdfontl.h
/usr/include/gdfontmb.h
/usr/include/gdfonts.h
/usr/include/gdfontt.h
/usr/lib/libgd.a

# MRTG files
%dir /home/httpd/html/mrtg
/home/httpd/html/mrtg/mrtg-l.png
/home/httpd/html/mrtg/mrtg-m.png
/home/httpd/html/mrtg/mrtg-r.png
/home/httpd/html/mrtg/mrtg-ti.png
%dir /etc/httpd/mrtg
%dir /etc/httpd/mrtg/doc
/etc/httpd/mrtg/doc/config.html
/etc/httpd/mrtg/doc/config.pod
/etc/httpd/mrtg/doc/config.txt
/etc/httpd/mrtg/doc/htaccess.txt
/etc/httpd/mrtg/doc/logfile-format.txt
/etc/httpd/mrtg/doc/manual.html
/etc/httpd/mrtg/doc/manual.txt
/etc/httpd/mrtg/doc/mibhelp.txt
/etc/httpd/mrtg/doc/mrtg-l.gif
/etc/httpd/mrtg/doc/mrtg-m.gif
/etc/httpd/mrtg/doc/mrtg-r.gif
/etc/httpd/mrtg/doc/mrtg-ti.gif
/etc/httpd/mrtg/doc/nt-guide.html
/etc/httpd/mrtg/doc/sample-mrtg.cfg
/etc/httpd/mrtg/doc/squid.txt
%dir /etc/httpd/mrtg/images
/etc/httpd/mrtg/images/mrtg-l.gif
/etc/httpd/mrtg/images/mrtg-l.png
/etc/httpd/mrtg/images/mrtg-m.gif
/etc/httpd/mrtg/images/mrtg-m.png
/etc/httpd/mrtg/images/mrtg-r.gif
/etc/httpd/mrtg/images/mrtg-r.png
/etc/httpd/mrtg/images/mrtg-ti.gif
/etc/httpd/mrtg/images/mrtg-ti.png
%dir /etc/httpd/mrtg/run
/etc/httpd/mrtg/run/BER.pm
/etc/httpd/mrtg/run/SNMP_Session.pm
/etc/httpd/mrtg/run/SNMP_util.pm
/etc/httpd/mrtg/run/cfgmaker
/etc/httpd/mrtg/run/cfgmaker_ip
/etc/httpd/mrtg/run/cfgmaker_phys
/etc/httpd/mrtg/run/indexmaker
/etc/httpd/mrtg/run/locales_mrtg.pm
/etc/httpd/mrtg/run/mrtg
/etc/httpd/mrtg/run/rateup
%config /etc/httpd/mrtg/run/mrtg.conf

# MRTG Graph viewer interface files
/etc/httpd/admin/viewgraph.pl

# MRTG Administration interface files
/etc/httpd/admin/Mrtg.pm
/etc/httpd/admin/mrtg-admin.pl

%changelog
* Wed Aug 9 2000 Erik Lotspeich <erik@electricc.com>

- Added URL tag to SPEC file.
- Made minor improvements to MRTG administration interface.
- Increased version number to 1.1.

* Fri Jul 21 2000 Erik Lotspeich <erik@electricc.com>

- MRTG Administration inteface added.  Other minor changes
to file layout and install scripts made.

* Sun Jul 16 2000 Erik Lotspeich <erik@electricc.com>

- MRTG Graph viewer script added.  Allows URL "/viewgraph" to be used
to view the available MRTG graphs.

* Mon Jun 30 2000 Erik Lotspeich <erik@electricc.com>

- Package development begins.
