#!/bin/sh
#
# Filename: install.sh
# Version: 1.1 (August 9, 2000)
# Author: Erik Lotspeich <erik@electricc.com>
#
# Description: This is an install script intended to be used with the
# MRTG package to aid in installation.  Expert users may prefer
# to install the package directly with "rpm", but this script should
# help novices who haven't mastered RPM and the concept of Linux
# packages.
# 
# Changelog
# ---------
# * June 15, 2000
# - Initial release
#
# * Aug 9, 2000
# - Will now remove gd-devel package along with the gd package.
# - Will exit after it realizes that a binary RPM doesn't exist for your machine.
#   Credit to Martino Piccinato <martino@corelli.nexus.it> for finding this bug.
#
# Copyright (C) 2000 The Electric Connection (http://www.electricc.com)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# Define some constants.
PRODUCT="anemone"
VERSION="1.0"
RELEASE="1"
PLATFORM=`uname -m`

# If platform is Intel, use i386.
if [ "$PLATFORM" = "i486" -o "$PLATFORM" = "i586" -o "$PLATFORM" = "i686" ]; then
    PLATFORM="i386"
fi

RPM_FILENAME="$PRODUCT-$VERSION-$RELEASE.$PLATFORM.rpm"

echo "install.sh 1.0 (MRTG 1.0)"
echo "Copyright (C) 2000 The Electric Connection (http://www.electricc.com)"
echo

echo -n "Detecting Platform ... "
echo "$PLATFORM detected"
echo

if [ ! -f $PRODUCT-$VERSION-$RELEASE.$PLATFORM.rpm ]; then
    echo "A binary RPM for your platform ($PLATFORM) was not detected."
    echo "You must build the package from the SRPM contained in this package."
    exit 1
fi

# Check whether the Apache package is installed.
if rpm -q mrtg > /dev/null ; then
    echo "An installation of MRTG has been detected on your system.  Since"
    echo "Anemone includes MRTG also, installation cannot continue until"
    echo "this conflict is resolved.  You should choose to remove MRTG from"
    echo "your system.  (RPM will save your MRTG configuration files.)"
    echo
    echo -n "Would you like to remove MRTG from your system? (y/n) "
    read ANSWER
    if [ "x$ANSWER" = "xy" -o "x$ANSWER" = "xyes" ]; then
	echo "Removing MRTG..."
	rpm -e mrtg --nodeps
    else
	echo
	echo "You have chosen to keep the MRTG you have installed."
	echo "Exiting ..."
	echo
	exit 1
    fi
fi

if rpm -q gd > /dev/null ; then
    echo "An installation of GD has been detected on your system.  Since"
    echo "Anemone includes GD also, installation cannot continue until"
    echo "this conflict is resolved.  You should choose to remove GD from"
    echo "your system.  Be aware that if you have any application that relies"
    echo "on the version of GD that is installed, you may have trouble with"
    echo "those applications.  If your application relies on the recent version"
    echo "of GD (provided here), then you will have no problems."
    echo
    echo -n "Would you like to remove GD from your system? (y/n) "
    read ANSWER
    if [ "x$ANSWER" = "xy" -o "x$ANSWER" = "xyes" ]; then
	echo "Removing GD..."
	rpm -e gd --nodeps
	rpm -e gd-devel --nodeps
    else
	echo
	echo "You have chosen to keep the MRTG you have installed."
	echo "Exiting ..."
	echo
	exit 1
    fi
fi

echo "Proceeding with installation."
echo "Installing $RPM_FILENAME ... "

rpm -Uvh $RPM_FILENAME

echo
echo "If RPM didn't print any errors above, the installation completed successfully."
echo
echo "If you were upgrading from a previous version of Anemone or are"
echo "migrating from a previous MRTG installation, you may have to"
echo "move your MRTG customizations to the Anemone-provided"
echo "configuration files.  Backups of your old files should have been saved"
echo "by RPM with the \".rpmsave\" or \".rpmorig\" extensions."
echo
echo "Thank you for using Anemone."
echo

exit 0;


