#
# Filename: Mrtg.pm
# Version 1.0
#
# Description: Administration interface for Anemone.
#
# Copyright (C) 2000 The Electric Connection (http://www.electricc.com)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

package Mrtg;
use Exporter;

@ISA=qw(Exporter);

@EXPORT=qw(
	   mrtg_status
	   get_refresh
	   get_interval
	   get_mrtg_cron
	   stop_mrtg
	   start_mrtg
	   write_refresh
	   write_interval
	   write_mrtg_cron
	   );

# References number to text in minutes.
%interval = (
#	     "1","1 minute",
#	     "2","2 minutes",
	     "5","5 minutes",
	     "10","10 minutes",
	     "20","20 minutes"
	     );

# References number of minutes to seconds.
%refresh = (
#	    "1","60",
#	    "2","120",
	    "5","300",
	    "10","600",
	    "20","1200"
	    );

# References number of seconds to minutes.
%unrefresh = (
#	      "60","1",
#	      "120","2",
	      "300","5",
	      "600","10",
	      "1200","20"
	      );

$mrtg_conf_file="/etc/httpd/mrtg/run/mrtg.conf";
$crontab_file="/etc/crontab";

sub mrtg_status {
    my ($crontab_entry);

    # This function checks to make sure that Cron is properly executing
    # MRTG.  If so, it returns true.
    
    open IN,$crontab_file or return 0;

    while (<IN>) {
	if ( $_ =~ /mrtg.*mrtg\.conf$/ ) {
	    $crontab_entry=$_;
	}
    }

    close IN;

    if ( $crontab_entry =~ /^\#.*mrtg/ ) {
	return 0;
    } else {
	return 1;
    }
}

sub get_refresh {
    my ($dir,$value);
    my ($refresh);

    # This function checks the value of the "Refresh" directive
    # in the MRTG configuration file.  It returns the value
    # once it finds it.

    open IN,$mrtg_conf_file or return 0;

    while (<IN>) {
	chop $_;
	($dir,$value)=split /\s+/,$_,2;
	if ( $_ =~ /^Refresh/ ) {
	    $refresh=$value;
	}
    }

    close IN;

    return $refresh;
}

sub get_interval {
    my ($dir,$value);
    my ($refresh);

    # This function returns the value of the Inverval
    # directive in the MRTG configuration file.

    open IN,$mrtg_conf_file or return 0;

    while (<IN>) {
	chop $_;
	($dir,$value)=split /\s+/,$_,2;
	if ( $_ =~ /^Interval/ ) {
	    $refresh=$value;
	}
    }

    close IN;

    return $refresh;
}

sub get_mrtg_cron {
    my ($minute,$hour,$dom,$month,$dow,$user,$command);

    # This function returns the time interval at which
    # MRTG is run in the crontab file.

    open IN,$crontab_file or return 0;

    while (<IN>) {
	chop $_;
	$_ =~ s/\#+//;
	($minute,$hour,$dom,$month,$dow,$user,$command)=split /\s+/,$_,7;
	if ( $_ =~ /mrtg.*mrtg\.conf$/ ) {
	    if ( $minute eq '*' ) {
		close IN;
		return 1;
	    } elsif ( $minute =~ s/\*\/// ) {
		close IN;
		return $minute;
	    } else {
		return 0;
	    }
	}
    }
    
    close IN;
    
    return 0;
}

sub start_mrtg {
    my ($file,$tmp_file);

    # This function enables MRTG in cron by uncommenting
    # the crontab entry.

    $file=$crontab_file;
    $tmp_file="/tmp/crontab";
    
    open IN,$file or return 0;
    open OUT,">".$tmp_file or return 0;

    while (<IN>) {
	if ( $_ =~ /mrtg.*mrtg\.conf$/ ) {
	    $_ =~ s/^(\#)+//;
	    print OUT $_;
	} else {
	    print OUT $_;
	}
    }

    close IN;
    close OUT;

    system "/etc/httpd/admin/crontab-update";

    return 1;
}

sub stop_mrtg {
    my ($file,$tmp_file);

    # This function disables MRTG in cron by commenting
    # out the crontab entry.

    $file=$crontab_file;
    $tmp_file="/tmp/crontab";
    
    open IN,$file or return 0;
    open OUT,">".$tmp_file or return 0;

    while (<IN>) {
	if ( $_ =~ /mrtg.*mrtg\.conf$/ ) {
	    print OUT "#".$_;
	} else {
	    print OUT $_;
	}
    }

    close IN;
    close OUT;

    system "/etc/httpd/admin/crontab-update";

    return 1;
}

sub write_refresh {
    local ($mrtg_freq=$_[0]);
    my ($dir,$value);
    
    # This function writes the value passed to the function
    # into the MRTG configuration file.  The argument passed to
    # this function should be a value in seconds.
    
    $file=$mrtg_conf_file;
    $tmp_file="/tmp/mrtg.conf";

    open IN,$file or return 0;
    open OUT,">".$tmp_file or return 0;

    while (<IN>) {
	($dir,$value)=split /\s+/,$_,2;
	if ( $_ =~ /Refresh/ ) {
	    print OUT "Refresh: $mrtg_freq\n";
	} else {
	    print OUT $_;
	}
    }
    
    close IN;
    close OUT;

    system "/etc/httpd/admin/mrtgconf-update";

    return 1;
}

sub write_interval {
    local ($mrtg_freq=$_[0]);
    my ($dir,$value);
    
    # This function writes the value passed to the function
    # into the MRTG configuration file.  The argument passed to
    # this function should be a value in seconds.
    
    $file=$mrtg_conf_file;
    $tmp_file="/tmp/mrtg.conf";

    open IN,$file or return 0;
    open OUT,">".$tmp_file or return 0;

    while (<IN>) {
	($dir,$value)=split /\s+/,$_,2;
	if ( $_ =~ /Interval/ ) {
	    print OUT "Interval: $mrtg_freq\n";
	} else {
	    print OUT $_;
	}
    }
    
    close IN;
    close OUT;

    system "/etc/httpd/admin/mrtgconf-update";

    return 1;
}

sub write_mrtg_cron {
    local ($mrtg_freq=$_[0]);
    my ($minute,$hour,$dom,$month,$dow,$user,$command);
    
    # This function writes the value passed to the function
    # into the MRTG configuration file.  The argument passed to
    # this function should be a value in seconds.
    
    $file=$crontab_file;
    $tmp_file="/tmp/crontab";

    open IN,$file or return 0;
    open OUT,">".$tmp_file or return 0;

    while (<IN>) {
	($minute,$hour,$dom,$month,$dow,$user,$command)=split /\s+/,$_,7;
	if ( $_ =~ /mrtg.*mrtg\.conf$/ ) {
	    if ( $mrtg_freq == 1 ) {
		print OUT "* * * * * root /etc/httpd/mrtg/run/mrtg ".
		    "/etc/httpd/mrtg/run/mrtg.conf\n";
	    } else {
		print OUT "*/$mrtg_freq * * * * root /etc/httpd/mrtg/run/mrtg ".
		    "/etc/httpd/mrtg/run/mrtg.conf\n";
	    }
	} else {
	    print OUT $_;
	}
    }
    
    close IN;
    close OUT;

    system "/etc/httpd/admin/crontab-update";

    return 1;
}

return 1;
