#!/usr/bin/perl -w
#
# Filename: admin.pl
# Version 1.0
#
# Description: Administration interface for Tomahawk.
#
# Copyright (C) 2000 The Electric Connection (http://www.electricc.com)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

use CGI qw(:standard :html3);
use Mrtg;
use Control;
use Crontab;
use Logs;
use Cache;

# Style sheet definitions
$LOCAL_STYLE=<<EOM;
BODY {
background: white;
color: black;
font-family: helvetica;
}
TD {
font-family: helvetica;
}
TH {
font-family: helvetica;
}
P {
font-family: helvetica;
font-size: 12pt
}
H1 {
font-family: helvetica;
}
H2 {
font-family: helvetica;
text-align: center;
}
SPAN.red {
color: red
}
SPAN.green {
color: green
}
EOM

# Do not edit below this line unless you know what you are doing!

# Print standard CGI header and HTML 4.0 DTD.
print header;
print start_html(-title=>"Anemone Administration",
		 -dtd=>'-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3c.org/TR/REC-html40/loose.dtd',
		 -style=>{
		     -code=>$LOCAL_STYLE
		     }
		 );

# Start with Tomahawk-specific layout.
	    print table({-border=>'0',-width=>'100%'},
		Tr([
		    td({-align=>LEFT,-valign=>MIDDLE},h1("Anemone Administration")).
		    td({-align=>RIGHT},img({-src=>'/admin_images/header.png',
					    -align=>RIGHT,
					    -alt=>'Header image'}) )
		    ]));

print hr();

# Process POST parameters.  Execute the appropriate functions.
if ( param(-name=>'mrtg-start') ) {
    start_mrtg();
    print_mrtg_status_form();
} elsif ( param(-name=>'mrtg-stop') ) {
    stop_mrtg();
    print_mrtg_status_form();
} elsif ( param(-name=>'save-mrtg-settings') ) {
    save_mrtg_settings();
    sleep 3;
    print_mrtg_status_form();
} else {
    print_mrtg_status_form();
}

print end_html;

exit 1;

sub print_mrtg_status_form {
    my ($mrtg_stat,$stat_str,$refresh,$interval);
    my ($default_interval);

    # This function prints the MRTG status form in the Anemone
    # administration interface.  It allows for viewing MRTG status
    # and changing basic settings.

    $mrtg_stat=mrtg_status();

    if ( $mrtg_stat ) {
	$stat_str="<SPAN class=\"green\">Running.</SPAN>";
    } else {
	$stat_str="<SPAN class=\"red\">Not running.</SPAN>";
    }

    $default_interval=get_mrtg_cron();

    # This function prints the main form with fields to fill out.
    print start_multipart_form(-action=>'/mrtg-admin');

    print h2("MRTG Status");

    print table({-border=>'0',-width=>'100%'},
		Tr([
		    th({-align=>CENTER},'MRTG').
		    td({-align=>CENTER},$stat_str),
		    td({-align=>CENTER,-colspan=>'2'},
		       'The following fields should be equivalent but '.
		       'can be different if you have unusual '.
		       'configuration needs.'),
		    th({-align=>CENTER},'Tells the browser how often '.
		       'to refresh the page.').
		    td({-align=>CENTER},
		       $Mrtg::interval{$Mrtg::unrefresh{get_refresh()}}),
		    th({-align=>CENTER},'Tells MRTG how often we will '.
		       'run it.').
		    td({-align=>CENTER},$Mrtg::interval{get_interval()}),
		    th({-align=>CENTER},'How often cron is running MRTG.').
		    td({-align=>CENTER},$Mrtg::interval{$default_interval})
		    ]));    

    if ( $mrtg_stat ) {
	print h2("MRTG Controls");

    # Small deviance from heavy use of CGI.pm functions for
    # increased HTML flexibility.
    print <<EOM;
<TABLE border="0" width="100%">
<TR>
<TH>Mrtg interval</TH>
<TD align="center">
EOM

    print "<SELECT name=\"mrtg-freq\">\n";
    sub numerically { $a <=> $b; }
    foreach $time (sort numerically keys %Mrtg::interval) {
	if ( $time == $default_interval ) {
	    print "<OPTION SELECTED value=\"$time\">$Mrtg::interval{$time}</OPTON>\n";
	} else {
	    print "<OPTION value=\"$time\">$Mrtg::interval{$time}</OPTON>\n";
	}
    }
    print "</SELECT>\n";

    print <<EOM;
</TD>
</TR>
</TABLE>
EOM

	print table({-border=>'0',-width=>'100%'},
		    Tr([
			th({-align=>CENTER},submit(-name=>'mrtg-stop',
						   -value=>'Stop MRTG')).
			th({-align=>CENTER},submit(-name=>'save-mrtg-settings',
						   -value=>'Save Settings'))
			]));
    } else {
		print table({-border=>'0',-width=>'100%'},
		    Tr([
			th({-align=>CENTER},submit(-name=>'mrtg-start',
						   -value=>'Start MRTG')),
			]));
    }

    print end_form;

    return 1;
}

sub save_mrtg_settings {
    my ($mrtg_freq);

    # This function saves the MRTG settings after the form
    # has been submitted with POST.

    $mrtg_freq=param(-name=>'mrtg-freq');

    # Write the changes to the appropriate configuration files.
    write_refresh($Mrtg::refresh{$mrtg_freq});
    write_interval($mrtg_freq);
    write_mrtg_cron($mrtg_freq);

    return 1;
}
