#!/usr/bin/perl -w
#
# Filename: mrtg.pl
# Version 1.0
#
# Description: Easy-to-use interface for MRTG.
#
# Copyright (C) 2000 The Electric Connection (http://www.electricc.com)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

use CGI qw(:standard :html3);

# Style sheet definitions
$LOCAL_STYLE=<<EOM;
BODY {
background: white;
color: black;
font-family: helvetica;
}
TD {
font-family: helvetica;
}
TH {
font-family: helvetica;
}
P {
font-family: helvetica;
font-size: 12pt
}
H1 {
font-family: helvetica;
}
H2 {
font-family: helvetica;
text-align: center;
}
SPAN.red {
color: red
}
SPAN.green {
color: green
}
EOM

# Do not edit below this line unless you know what you are doing!

# Print standard CGI header and HTML 4.0 DTD.
print header;
print start_html(-title=>"Anemone Sample Graphs",
		 -dtd=>'-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3c.org/TR/REC-html40/loose.dtd',
		 -style=>{
		     -code=>$LOCAL_STYLE
		     }
		 );

# Start with Flamehawk-specific layout.
	    print table({-border=>'0',-width=>'100%'},
		Tr([
		    td({-align=>LEFT,-valign=>MIDDLE},h1("Anemone Sample Graphs")).
		    td({-align=>RIGHT},img({-src=>'/admin_images/header.png',
					    -align=>RIGHT,
					    -alt=>'Header image'}) )
		    ]));

print hr();

print h1("Available MRTG graphs");

@graphfiles=get_mrtg_graphs();

print "<UL>\n";

foreach $file (@graphfiles) {
    print "<LI>";
    print "<A HREF=\"http://".get_domainname()."/mrtg/$file\">$file</A>";
    print "</LI>\n";
}

print "</UL>\n";

print end_html;

exit 1;

sub get_mrtg_graphs {
    my (@allfiles,$file);
    my (@graphfiles);

    # This function looks in the mrtg directory and returns
    # a list of HTML files in that directory.  These files
    # are the graphs that MRTG generated.  The filenames are
    # returned in an array.

    opendir MRTG,"/home/httpd/html/mrtg" or return 0;

    @allfiles=readdir MRTG;
   
    closedir MRTG;

    foreach $file (@allfiles) {
	if ( $file =~ /\.html$/ ) {
	    push @graphfiles,$file;
	}
    }

    return @graphfiles;
}

sub get_domainname {
    my ($domainname);
    my ($FQ_HOSTNAME);
    
    # This function finds out the domain name of the current
    # machine and returns it.

    $FQ_HOSTNAME=`hostname`;

    chop $FQ_HOSTNAME;

    return $FQ_HOSTNAME;
}
